[PATCH] comctl32/tests: Mark smaller propsheet buffer as broken

Alex Henrie alexhenrie24 at gmail.com
Sun Dec 26 21:30:19 CST 2021


Fixes another testbot failure.

Signed-off-by: Alex Henrie <alexhenrie24 at gmail.com>
---
 dlls/comctl32/tests/propsheet.c | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/dlls/comctl32/tests/propsheet.c b/dlls/comctl32/tests/propsheet.c
index 4621d2c8c38..affd21da825 100644
--- a/dlls/comctl32/tests/propsheet.c
+++ b/dlls/comctl32/tests/propsheet.c
@@ -92,8 +92,11 @@ static int CALLBACK sheet_callback(HWND hwnd, UINT msg, LPARAM lparam)
         size = SizeofResource(module, hrsrc);
         ok(size != 0, "Failed to get size of propsheet dialog resource\n");
         buffer_size = HeapSize(GetProcessHeap(), 0, (void *)lparam);
-        /* Hebrew Windows 10 allocates 2 * size + 8, all others allocate 2 * size */
-        ok(buffer_size >= 2 * size, "Unexpected template buffer size %u, resource size %u\n",
+        /* Hebrew Windows 10 allocates 2 * size + 8,
+         * Arabic Windows 10 allocates 2 * size - 32,
+         * all others allocate exactly 2 * size */
+        ok(buffer_size >= 2 * size || broken(buffer_size == 2 * size - 32),
+                "Unexpected template buffer size %u, resource size %u\n",
                 buffer_size, size);
         break;
       }
-- 
2.34.1




More information about the wine-devel mailing list